
static char help[] = "Demonstrates a un-logical behaviour in VecLoad.\n\n";


#include <petscvec.h>
#include <petscviewerhdf5.h>


int main(int argc, char **argv)
{
  Vec            x, y;
  PetscViewer    viewer;
  PetscErrorCode ierr;

  ierr = PetscInitialize(&argc, &argv, (char*)0, help);CHKERRQ(ierr);

  ierr = VecCreate(PETSC_COMM_SELF, &x);CHKERRQ(ierr);
  ierr = VecCreate(PETSC_COMM_SELF, &y);CHKERRQ(ierr);
  
  ierr = VecSetType(x, VECSEQ);CHKERRQ(ierr);
  ierr = VecSetType(y, VECSEQ);CHKERRQ(ierr);
  
  ierr = PetscObjectSetName((PetscObject) x, "x");CHKERRQ(ierr);
  ierr = PetscObjectSetName((PetscObject) y, "y");CHKERRQ(ierr);
  
  
  ierr = PetscViewerHDF5Open(PETSC_COMM_WORLD, "input.h5", FILE_MODE_READ, &viewer);CHKERRQ(ierr);
  
  
  // Test 1: Try to load the vector y. This vector has two 
  // dimensions, of size 21x1, and this works.
  ierr = VecLoad(y, viewer);CHKERRQ(ierr);
  
  // Get the size of this vector and its max and min values to verify
  // that it is loaded correctly
  PetscInt size;
  ierr = VecGetSize(y, &size);CHKERRQ(ierr);
  fprintf(stdout, "Loaded %d elements into Vec y.\n", (int)size);
  
  PetscScalar min,max;
  PetscInt minLoc, maxLoc;
  ierr = VecMin(y, &minLoc, &min); CHKERRQ(ierr);
  ierr = VecMax(y, &maxLoc, &max); CHKERRQ(ierr);
  
  fprintf(stdout, "Minimum value in vector y is %f at position %d\n", min, (int)minLoc);
  fprintf(stdout, "Maximum value in vector y is %f at position %d\n", max, (int)maxLoc);
  
  
  // Test 2: Try to load the vector x. This vector contains
  // the same data as x, but has only one dimension, with size of 21.
  // This does not work.
  ierr = VecLoad(x, viewer);CHKERRQ(ierr);
  
  
  ierr = PetscViewerDestroy(&viewer);CHKERRQ(ierr);
  ierr = VecDestroy(&y);CHKERRQ(ierr);
  ierr = VecDestroy(&x);CHKERRQ(ierr);
  ierr = PetscFinalize();
  return 0;
}


